package org.artifactory.queue;

import lombok.Builder;
import lombok.NonNull;
import lombok.Value;
import org.artifactory.event.work.NodeEventsErrorsBackOffStrategy;
import org.artifactory.queue.behaviors.QueueReductionBehaviours;
import org.artifactory.queue.error.PersistentQueueBackoffStrategy;
import org.artifactory.storage.db.event.entity.NodeEventCursorType;

import javax.annotation.Nonnegative;
import javax.annotation.Nullable;

/**
 * @author avishayh
 */
@Value
@Builder
public class QueueConfiguration {

    /**
     * the cursorType for the queue (NodeEventCursorType.markerType must be EventId)
     * will be added to the name of the queue
     * (e.g: INCREMENTAL_INDEX, FEDERATED_REPLICATION)
     */
    @NonNull
    NodeEventCursorType cursorType;
    @NonNull
    QueueEventImplementor implementor;
    /**
     * variant can be used to create more than one queue for the same use case.
     * it will be added to name of the queue (will be saved in cursor table)
     * (e.g: replication's target id)
     */
    @NonNull
    @Builder.Default
    String variant = "";

    //db querying configuration
    @Nullable
    String fileSuffix;
    @Builder.Default
    int maxBulkSize = 1000;

    //filtering configuration
    @Builder.Default
    @NonNull
    QueueReductionBehaviours reductionBehaviours = QueueReductionBehaviours.Basic;
    @Nullable
    QueueEventFilter filter;

    //concurrency configuration
    /**
     * divide work into groups
     */
    @Nullable
    QueueEventAggregator aggregator;
    /**
     * maximum threads to handle aggregator's groups
     */
    @Builder.Default
    int threads = 5;

    //error handling configuration
    /**
     * enable flag for error handling
     */
    @Builder.Default
    boolean enableErrorSupport = true;
    /**
     * number of retires for a specific error before deleting it
     */
    @Nonnegative
    @Builder.Default
    int maxErrorRetires = 6;
    /**
     * number of errors which declares overflow status
     * set to 0 to disable the overflow status
     */
    @Nonnegative
    @Builder.Default
    int errorOverflowLimit = 1000;

    /**
     * backoff strategy for error
     */
    @Builder.Default
    @NonNull
    NodeEventsErrorsBackOffStrategy backoffStrategy = new PersistentQueueBackoffStrategy(4, 30);

}
