package org.artifactory.projects;

import org.apache.commons.lang3.builder.DiffBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import org.artifactory.api.security.AuthorizationService;
import org.artifactory.config.CentralConfigKey;
import org.jfrog.common.config.diff.DiffMerger;
import org.mockito.Mock;
import org.testng.Assert;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import java.sql.SQLException;

import static org.mockito.Mockito.when;
import static org.mockito.MockitoAnnotations.initMocks;

/**
 * @author BarakH
 */
@Test
public class ProjectAdminValidationTest {

    private ProjectAdminValidation projectAdminValidator = null;

    @Mock
    private AuthorizationService authService;

    @DataProvider
    public static Object[][] provideFieldNames() {
        return new Object[][] {
                {CentralConfigKey.localRepositoriesMap.getKey(), true},
                {CentralConfigKey.remoteRepositoriesMap.getKey(), true},
                {CentralConfigKey.virtualRepositoriesMap.getKey(), true},
                {CentralConfigKey.distributionRepositoriesMap.getKey(), true},
                {CentralConfigKey.releaseBundlesRepositoriesMap.getKey(), true},
                {"repoLayouts", true},
                {CentralConfigKey.localReplications.getKey(), false},
                {"", false},
                {null, false},
        };
    }

    @BeforeClass
    public void setUp() throws SQLException {
        initMocks(this);
        projectAdminValidator = new ProjectAdminValidation(authService);
    }

    @Test(dataProvider = "provideFieldNames")
    public void testIsProjectAdminAllowedToSaveConfigChanges(String fieldName, boolean shouldBeAllowed) {
        when(authService.isAdmin()).thenReturn(shouldBeAllowed);
        DiffBuilder db = new DiffBuilder("a", "b", ToStringStyle.DEFAULT_STYLE, false);
        db.append(fieldName, "a", "b");
        if (!shouldBeAllowed) {
            Assert.assertThrows(IllegalArgumentException.class,
                    () -> projectAdminValidator.validate(DiffMerger.diffToDataDiff(db.build().getDiffs())));
        } else {
            projectAdminValidator.validate(DiffMerger.diffToDataDiff(db.build().getDiffs()));
        }
    }
}
