package org.artifactory.ui.rest.service.admin.security.group;

import edu.emory.mathcs.backport.java.util.Collections;
import org.artifactory.api.security.UserGroupService;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.ArtifactoryRestResponse;
import org.artifactory.ui.rest.model.admin.security.group.Group;
import org.jfrog.access.client.AccessClientException;
import org.jfrog.access.client.AccessClientHttpException;
import org.jfrog.access.rest.group.GroupResponse;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;
import static org.mockito.Mockito.when;

@Test
public class UpdateGroupServiceTest {

    @Mock
    private UserGroupService userGroupService;
    @Mock
    private ArtifactoryRestRequest artifactoryRestRequest;
    @Mock
    private GroupResponse groupResponse;

    private UpdateGroupService updateGroupService;

    @BeforeMethod
    public void setUp() {
        MockitoAnnotations.initMocks(this);
        updateGroupService = new UpdateGroupService();
        updateGroupService.setUserGroupService(userGroupService);
    }

    @Test
    public void executeCorrectResponseAccessHttpExceptionExpectErrorResponse() {
        Group mutableGroupInfo = new Group("testGroup");
        mutableGroupInfo.setUsersInGroup(Collections.singletonList("TestUser"));
        when(artifactoryRestRequest.getImodel()).thenReturn(mutableGroupInfo);
        when(artifactoryRestRequest.getPathParamByKey("id")).thenReturn("testRequestId");
        ArtifactoryRestResponse restResponse = new ArtifactoryRestResponse();
        when(userGroupService.updateGroup(mutableGroupInfo))
                .thenThrow(new AccessClientHttpException(409, "TestFailMessage"));
        updateGroupService.execute(artifactoryRestRequest, restResponse);
        assertTrue(restResponse.getFeedbackMsg().getError().contains("Failed to update group testGroup."));
        assertEquals(409, restResponse.getResponseCode());
    }

    @Test
    public void executeCorrectResponseExpectErrorResponse() {
        Group mutableGroupInfo = new Group("testGroup");
        mutableGroupInfo.setUsersInGroup(Collections.singletonList("TestUser"));
        when(artifactoryRestRequest.getImodel()).thenReturn(mutableGroupInfo);
        when(artifactoryRestRequest.getPathParamByKey("id")).thenReturn("testRequestId");
        ArtifactoryRestResponse restResponse = new ArtifactoryRestResponse();
        when(userGroupService.updateGroup(mutableGroupInfo))
                .thenThrow(new AccessClientException("TestFailMessage"));
        updateGroupService.execute(artifactoryRestRequest, restResponse);
        assertTrue(restResponse.getFeedbackMsg().getError().contains("Failed to update group testGroup."));
        assertEquals(500, restResponse.getResponseCode());
    }

    @Test
    public void executeCorrectResponseExpect() {
        Group mutableGroupInfo = new Group("testGroup");
        mutableGroupInfo.setUsersInGroup(Collections.singletonList("TestUser"));
        when(artifactoryRestRequest.getImodel()).thenReturn(mutableGroupInfo);
        when(artifactoryRestRequest.getPathParamByKey("id")).thenReturn("testRequestId");
        ArtifactoryRestResponse restResponse = new ArtifactoryRestResponse();
        when(userGroupService.updateGroup(mutableGroupInfo))
                .thenReturn(groupResponse);
        updateGroupService.execute(artifactoryRestRequest, restResponse);
        assertEquals(200, restResponse.getResponseCode());
    }

}
